
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

            #include <glib-object.h>


            G_BEGIN_DECLS

/* enumerations from "gdata-media-content.h" */


GType gdata_media_expression_get_type (void);
#define GDATA_TYPE_MEDIA_EXPRESSION (gdata_media_expression_get_type())


GType gdata_media_medium_get_type (void);
#define GDATA_TYPE_MEDIA_MEDIUM (gdata_media_medium_get_type())

G_END_DECLS

/* Generated data ends here */

